--- system.pas.orig	Thu Jan  1 00:08:17 2004
+++ system.pas	Wed May  5 11:14:04 2004
@@ -10,7 +10,7 @@
   used BP or Delphi before, you don't want to look at this unit. :-)
 
   This unit depends on the conditional defines `__BP_TYPE_SIZES__',
-  `__BP_RANDOM__' and `__BP_PARAMSTR_0__'.
+  `__BP_RANDOM__', `__BP_PARAMSTR_0__' and `__BP_NO_ALLOCMEM__'.
 
   If `__BP_TYPE_SIZES__' is defined (with the `-D__BP_TYPE_SIZES__'
   option), the integer data types will be redefined to the sizes
@@ -41,6 +41,12 @@
   systems. For most cases where BP programs access their own
   executable, there are cleaner alternatives available.
 
+  If `__BP_NO_ALLOCMEM__' is defined (`-D__BP_NO_ALLOCMEM__'), the
+  two Delphi compatible functions `AllocMemCount' and `AllocMemSize'
+  will not be provided. The advantage is that this unit will not
+  have to `Mark' the heap which makes memory de-/allocations much
+  faster if the program doesn't use `Mark' otherwise.
+
   Copyright (C) 1998-2004 Free Software Foundation, Inc.
 
   Authors: Peter Gerwinski <peter@gerwinski.de>
@@ -318,8 +324,10 @@
 
 function  CompToDouble (x: Comp): Double; attribute (name = '_p_CompToDouble');
 function  DoubleToComp (x: Double): Comp; attribute (name = '_p_DoubleToComp');
+{$ifndef __BP_NO_ALLOCMEM__}
 function  AllocMemCount: SystemInteger;   attribute (name = '_p_AllocMemCount');
 function  AllocMemSize: SizeType;         attribute (name = '_p_AllocMemSize');
+{$endif}
 procedure Assert (Condition: Boolean);    attribute (name = '_p_System_Assert');
 procedure DefaultAssertErrorProc (const Message, FileName: String; LineNumber: SystemInteger; ErrorAddr: Pointer); attribute (name = '_p_DefaultAssertErrorProc');
 
@@ -491,7 +499,10 @@
   OldFreeMem  : FreeMemType;
   MaxAvailSave: Pointer = nil;
   MaxAvailSize: SizeType = 0;
-  FirstMark   : Pointer;
+
+{$ifndef __BP_NO_ALLOCMEM__}
+var
+  FirstMark: Pointer;
 
 function AllocMemCount = Count: SystemInteger;
 
@@ -525,6 +536,7 @@
   Size := 0;
   ForEachMarkedBlock (FirstMark, CountBlockSize)
 end;
+{$endif}
 
 function BPGetMem (Size: SizeType) = p: Pointer;
 var Status: SystemInteger;
@@ -805,7 +817,9 @@
     CmdLineStr := ParamStr (1);
     for i := 2 to ParamCount do CmdLineStr := CmdLineStr + ' ' + ParamStr (i);
     CmdLine := CmdLineStr;
+    {$ifndef __BP_NO_ALLOCMEM__}
     Mark (FirstMark)
+    {$endif}
   end;
 
 to end do
